#!/usr/bin/perl
$usage = <<'EOF' ;
#----------------------------------------
# Euler solver
#
# usage: euler.pl [-d <duration>] <ode-filename>
#	<duration> : how many msec to simulate
#
# ode file rules:  
#	- all variables must start with '$var'
#	- all parameters must start with '$par'
#	- references must be set for '$var' pointing to $vec[$i]
#	- initial values must be set using an array
#
#	reserved variables are:
#		$t : step variable 
#		$time: current time
#		$h : step size
#		$duration : simulation duration
#		@vec : state vector array
#		@newVec : new state vector array
#		@ode_func : functions
#		$ode_exec : commands to execute each step
#
#----------------------------------------
EOF

#----------------------------------------
# Print help message
#----------------------------------------
require "getopts.pl";
&Getopts('hd:');

if ($opt_h || ($#ARGV==-1)) {
	print $usage;
	exit(0);
}

$duration = ($opt_d)?$opt_d:1000;

#----------------------------------------
# Defaults 
#----------------------------------------
$h = 0.1;	# integrate step size
$cond = "";

#--------------------
# read in ode file
#--------------------
do "$ARGV[0]";

$time = 0.0;
$iters = $duration / $h;
for ($t = 0; $t<$iters; ++$t) {
	print $time;
	for ($k=0; $k<=$#vec; ++$k) {
		$newVec[$k] = $vec[$k] + $h*(eval $ode_func[$k]);
		print " $newVec[$k]";
	}
   	print "\n";
	@vec =  @newVec;
	eval $ode_exec;
	$time += $h;

}


