//----------------------------------------------------------------------------
// 
//	file: inputlist.h
// 
//	function: maintain list of input spec and return it when prompted 
//	author:   Yoonsuck Choe <yschoe@cs.utexas.edu>
//	creation: Wed Feb  3 23:41:05 CST 1999
// 
//	$Revision: 1.2 $ $Date: 2001/11/30 20:24:15 $
//	$Log: inputlist.h,v $
//	Revision 1.2  2001/11/30 20:24:15  yschoe
//	pglissom v1.0 release
//
//	Revision 1.1  1999/02/09 07:42:25  yschoe
//	Initial revision
//
//
//----------------------------------------------------------------------------

#include "geninput.h"
#include "real.h"

enum IL_TYPE { IL_INT, IL_REAL };

// holds a single argument of a single input spec
typedef union {	
	int	i;
	REAL	r;
} IL_Data;

class inputlist {

  int	   max_specs;	// max number of specs 
  int	   num_specs; 	// number of specs 
  IL_Data  **table;	// input spec table : table[spec_num][arg_index]
  INP_TYPE *type_table; // input type table 
  geninput *input_obj;	// pointer to geninp object

public: 

  inputlist(int max_specs, geninput *input);
  ~inputlist();

  // add input spec to the table
  void  add_spec(int cx, int cy, int radius);
  void  add_spec(int cx, int cy, int width, int height, REAL angle);
  void  add_spec(int cx, int cy, REAL sigma);
  void  add_spec(int x, int y, REAL sigma, REAL slope);
  void  add_spec(int cx, int cy, REAL sigmax, REAL sigmay, REAL angle);
  void  add_spec(int cx, int cy, int freq, REAL phase, REAL angle);
  void  add_spec(int imgidx);

  // simenv interface
  int   call_add_spec_rect(int argc, char *argv[]); 
  int   call_add_spec_ori_line(int argc, char *argv[]);
  int   call_add_spec_gaus(int argc, char *argv[]);
  int   call_add_spec_ori_gaus(int argc, char *argv[]);
  int   call_add_spec_sin(int argc, char *argv[]);
  int   call_add_spec_blobs(int argc, char *argv[]);
  int   call_add_spec_img(int argc, char *argv[]);

  void  clear_specs() { num_specs = 0; }
  int   call_clear(int argc, char *argv[]) { clear_specs(); return 1; }

  void  add_inputs();
  int   call_add_inputs(int argc, char *argv[]) { add_inputs(); return 1;}

};
