//----------------------------------------------------------------------------
// 
//	file: latw_window.cc
// 
//	function: lateral weight display window
//	author:   Yoonsuck Choe <yschoe@cs.utexas.edu>
//	creation: Fri Oct 23 06:04:50 CDT 1998
// 
//	$Revision: 1.2 $ $Date: 1999/02/09 07:42:25 $
//	$Log: latw_window.cc,v $
//	Revision 1.2  1999/02/09 07:42:25  yschoe
//	instar-outstar is not explicitly selectable
//
//	Revision 1.1  1998/10/26 03:47:56  yschoe
//	Initial revision
//
//
//----------------------------------------------------------------------------
#include "latw_window.h"

//----------------------------------------------------------------------------
//	latw_window() 
//	  - constructor
//----------------------------------------------------------------------------
latw_window::latw_window(char *name, netlayer *map, int width, int height, 
	LATW_TYPE sel, REAL multiplier,
	int is_instar) 
 	: affw_window(name, map,width,height,map->cols,map->rows,0) { 

  // for brighter display
  mult = multiplier;
  selection = sel;

  // weight mode -- instar or outstar?
  latw_window::is_instar = is_instar;

}

//----------------------------------------------------------------------------
//	~latw_window() 
//	  - destructor
//----------------------------------------------------------------------------
latw_window::~latw_window() {

  // no need to do anything here.
}
  
//----------------------------------------------------------------------------
//	redraw() 
//	  - fill in the matrix and redraw
//----------------------------------------------------------------------------
void latw_window::redraw() {

  // 1. draw latw boundaries
  for (int i=0; i<sizex; ++i) {
     for (int j=0; j<sizey; ++j) {

	if ((i+1)%(aff_cols+1)==0 || (j+1)%(aff_rows+1)==0)  
		multi_matrix[i][j] = 1.0;   

     }
  }

  // 2. now fill in with the lateral weights
  for (int i=0; i<cols; ++i) {
     for (int j=0; j<rows; ++j) {
		
	int offset_x = (aff_cols+1)*i;
	int offset_y = (aff_rows+1)*j;

	switch (selection) {
	   case LATW_INH : map->get_lat_inhw(buffer_matrix,i,j,is_instar);break;
	   case LATW_EXC : map->get_lat_excw(buffer_matrix,i,j,is_instar);break;
	   case LATW_COMB : map->get_lat_combinedw(buffer_matrix,i,j); break;
	}	
	
	for (int k=0; k<aff_cols; ++k)
	   for (int l=0; l<aff_rows; ++l)
		multi_matrix[k+offset_x][l+offset_y] = buffer_matrix[k][l]*mult;
     }
  }

  matw->redraw();
  XFlush(display);

}

