## usage: [Vmax,Eimg] = convedgematcomphg(Img, kernelsize, gridsize, freq,theta)
##
##	Img: p x q matrix (grayscale image)
##
##		Img: 2D matrix with grayscale image
##		kernelsize: width (==height) of convolution kernel
##		gridsize:   sampling grid size
##		freq: 	    gabor frequency (relative to the kernelsize) 
##              theta:      gabor orientation
##
## Returns a n x m matrix E where 
##	n = p / gridsize
##	m = q / gridsize
##	and each E_ij is the edge orientation of the subimage patch.
##
## First, convolve with DoG filter, and then convolve with gabor
## filter of orientation theta. Do a polar addition. Cut the generated
## images into patches and find the mximum value and the index	
##
##	Usage example:
##		[Vmax,Eimg] = convedgematnew(imagemat,9,3,1);
##
##		both DoG and gabor filters are  9 x 9, and
##		Gabor frequency is 1.
##		final grid sampling size is 3 x 3.
##
## $Id: convedgemat.m,v 1.2 2002/03/09 17:31:27 yschoe Exp yschoe $

function [Vmax,Eimg] = convedgematcomphg(Img, kernelsize, gridsize, freq, theta)

	# get image size
	[oldp, oldq] = size(Img);

	# adjust grid size to have the conv kernels
	# centered at the middle: i.e. make the gridsize an odd number.
	if ( rem(kernelsize,2) == 0 ) 
		kernelsize ++;
	endif

	DoG = dog(kernelsize);

        # convolve with DoG, and only use the abs part
	Eimg = real(conv2(Img,DoG,"same"));	
	    
        # calculate new image size to make it divisible by gridsize
	p = floor(oldp/gridsize)*gridsize;
	q = floor(oldq/gridsize)*gridsize;

   	ygrids = floor(p/gridsize);
	xgrids = floor(q/gridsize);

	#initialize matrices
	V = zeros(ygrids,xgrids).-999999;
	
        Vmax=zeros(oldp,oldq);
	V1max=zeros(oldp,oldq);

	g1 = gabor(kernelsize,kernelsize,"sin",theta,freq);
	g2 = gabor(kernelsize,kernelsize,"cos",theta,freq);

        V1max=real(conv2(Eimg,g1,"same")).^2+real(conv2(Eimg,g2,"same")).^2;
        
        Vmax=V1max;

endfunction
