## Copyright (C) 2000 uschoe
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2, or (at your option)
## any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, write to the Free
## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
## 02111-1307, USA.

## usage: gabor_old(N,M,["sin"|"cos"],theta,freq,sigmax,sigmay,centerx,centery)
##
## Returns a NxM matrix with gabor sigmax and sigmay with orientation theta.
## with phase and freq
##

## Author: Yoonsuck Choe <yschoe@cs.utexas.edu>

function g = gabor_old (N, M, modfunc, theta, freq, sigmax, sigmay, cx, cy)

  if (nargin < 8)
	cx = N/2; cy = M/2;
  endif
  if (nargin < 6) 
	sigmax = N/4; sigmay = M/4;
  endif
  if (nargin < 5) 
	freq = 2;
  endif
  if (nargin < 4) 
	th = 0;
  else
	th = theta;
  endif
  if (nargin < 3) 
	modfunc = "sin";
  endif

  modfunc 
  th 

  radian = th * pi / 180.0;

  for i=1:N ;
	for j=1:M ;
		xsq = ((cx-j)*cos(radian)+(cy-i)*sin(radian))**2/(sigmay**2);
		ysq = (-(cx-j)*sin(radian)+(cy-i)*cos(radian))**2/(sigmax**2);
		g(i,j) = exp(-(xsq+ysq));
	endfor
  endfor

  freq_radian = freq * 2 * 3.141592;

  if (modfunc=="sin") 
  	sm = sinmat(N,freq,th);
  else
  	sm = cosmat(N,freq,th);
  endif
  g = g.*sm;

endfunction
